.. _underthehood:

===========================================
Under-the-hood Documentation for developers
===========================================

These documents are intended as a low-level look into NumPy; focused
towards developers.

.. toctree::
   :maxdepth: 1

   internals
   internals.code-explanations
   alignment
